{% extends "base.html" %}

{% block content %}
    {% if verified %}
        {% if moderated %}
            Your account has been verified. Account moderators have been notified
            and will begin reviewing your account request.
        {% else %}
            Your account has been verified. You can now <a href="{% url login %}">login</a>.
        {% endif %}
    {% else %}
        This account has already been verified or does not exist. No further action is necessary.
    {% endif %}
{% endblock %}
