{% extends "base.html" %}

{% block content %}
    <form method="post" action="">
        {% csrf_token %}
        <input type="hidden" name="next" value="{{ next }}">
        
        <table>
            <tr>
                <th>{{ form.username.label_tag }}</th>
                <td>{{ form.username}}</td>
            </tr>
            <tr>
                <th>{{ form.password.label_tag }}</th>
                <td>{{ form.password }}
                    <div><a href="{% url password-reset %}">Forget password?</a></div>
                </td>
            </tr>
        </table>

        <div style="controls">
            <input type="submit" value="Login">
        </div>
    </form>
{% endblock %}
