{% extends "base.html" %}

{% block content %}
    {% if valid_reset_link %}                   
        <form method="post" action="">
            {% csrf_token %}
            <table>
                <tr>
                    <th>{{ form.new_password1.label_tag }}</th>
                    <td>{{ form.new_password1 }}<br>
                        <span class="info">{{ form.new_password1.help_text }}</span> 
                    </td>
                </tr>
                <tr>
                    <th>{{ form.new_password2.label_tag }}</th>
                    <td>{{ form.new_password2 }}</td>
                </tr>                    
            </table>

            <div style="text-align:right">
                <input type="submit" value="Reset Password">
            </div>
        </form>
    {% else %}
        This password reset link is not valid. Try resetting
        your password <a href="{% url password-reset %}">again</a>.
    {% endif %}
{% endblock %}
