{% extends "base.html" %}

{% block content %}
    <form method="post" action="">
        {% csrf_token %}
        <table>
            <tr>
                <th>{{ form.email.label_tag }}</th>
                <td>{{ form.email }}</td>
            </tr>
        </table>
        <div class="controls">
            <input type="submit" value="Reset Password">
        </div>
    </form>
{% endblock %}
